@@ -486,30 +486,6 @@ class ManifestFile():
         return 'ManifestFile(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
 
 
-class Placeholders(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/cdk-assets-schema.Placeholders"):
-    """Placeholders which can be used in the destinations."""
-    def __init__(self) -> None:
-        jsii.create(Placeholders, self, [])
-
-    @jsii.python.classproperty
-    @jsii.member(jsii_name="CURRENT_ACCOUNT")
-    def CURRENT_ACCOUNT(cls) -> str:
-        """Insert this into the destination fields to be replaced with the current account."""
-        return jsii.sget(cls, "CURRENT_ACCOUNT")
-
-    @jsii.python.classproperty
-    @jsii.member(jsii_name="CURRENT_PARTITION")
-    def CURRENT_PARTITION(cls) -> str:
-        """Insert this into the destination fields to be replaced with the current partition."""
-        return jsii.sget(cls, "CURRENT_PARTITION")
-
-    @jsii.python.classproperty
-    @jsii.member(jsii_name="CURRENT_REGION")
-    def CURRENT_REGION(cls) -> str:
-        """Insert this into the destination fields to be replaced with the current region."""
-        return jsii.sget(cls, "CURRENT_REGION")
-
-
 __all__ = [
     "AssetManifestSchema",
     "AwsDestination",
@@ -521,7 +497,6 @@ __all__ = [
     "FileDestination",
     "FileSource",
     "ManifestFile",
-    "Placeholders",
 ]
 
 publication.publish()
